@@ -143,7 +143,7 @@ def set_up_model_artifact(artifact_folder, model_name):
                 return model_id
             else:
                 message = f"Existing artifacts won't be used ({ENV=})"
-                raise logging.warning(message)
+                logging.warning(message)
         logging.info("Download serialized model")
         model_id = download_model_version(model_name, ENV, artifact_folder)
     else:
